@@ -25,10 +25,10 @@
 //! # // The Safe Client is an sync library so will need some kind of runtime. Here we use tokio.
 //! # extern crate tokio; use anyhow::Result;
 //! # use safe_network::client::utils::test_utils::read_network_conn_info;
-//! use safe_network::client::Client;
+//! use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
 //! # #[tokio::main] async fn main() { let _: Result<()> = futures::executor::block_on( async {
 //! # let bootstrap_contacts = Some(read_network_conn_info()?);
-//! let client = Client::new(None, None, bootstrap_contacts).await?;
+//! let client = Client::new(None, None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
 //! // Now for example you can perform read operations:
 //! let _some_balance = client.get_balance().await?;
 //! # Ok(()) } ); }
@@ -39,14 +39,14 @@
 //! ```no_run
 //! # // The Safe Client is an sync library so will need some kind of runtime. Here we use tokio.
 //! # extern crate tokio; use anyhow::Result;
-//! # use safe_network::client::utils::test_utils::read_network_conn_info;
-//! use safe_network::client::Client;
+//! # use safe_network::client::{utils::test_utils::read_network_conn_info};
+//! use safe_network::client::{Client, DEFAULT_QUERY_TIMEOUT};
 //! use rand::rngs::OsRng;
 //! use safe_network::types::Keypair;
 //! # #[tokio::main] async fn main() { let _: Result<()> = futures::executor::block_on( async {
 //! let id = Keypair::new_ed25519(&mut OsRng);
 //! # let bootstrap_contacts = Some(read_network_conn_info()?);
-//! let client = Client::new(Some(id), None, bootstrap_contacts).await?;
+//! let client = Client::new(Some(id), None, bootstrap_contacts, DEFAULT_QUERY_TIMEOUT).await?;
 //! // Now for example you can perform read operations:
 //! let _some_balance = client.get_balance().await?;
 //! # Ok(()) } ); }
@@ -66,5 +66,8 @@ pub mod client_api;
 /// Config file handling.
 pub mod config_handler;
 
+/// Default timeout in
+pub const DEFAULT_QUERY_TIMEOUT: u64 = 20; // 20 seconds
+
 /// Utility functions.
 pub mod utils;
